
#ifndef MAILIMPORTERAKONADI_EXPORT_H
#define MAILIMPORTERAKONADI_EXPORT_H

#ifdef MAILIMPORTERAKONADI_STATIC_DEFINE
#  define MAILIMPORTERAKONADI_EXPORT
#  define MAILIMPORTERAKONADI_NO_EXPORT
#else
#  ifndef MAILIMPORTERAKONADI_EXPORT
#    ifdef KPim6MailImporterAkonadi_EXPORTS
        /* We are building this library */
#      define MAILIMPORTERAKONADI_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define MAILIMPORTERAKONADI_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef MAILIMPORTERAKONADI_NO_EXPORT
#    define MAILIMPORTERAKONADI_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef MAILIMPORTERAKONADI_DECL_DEPRECATED
#  define MAILIMPORTERAKONADI_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MAILIMPORTERAKONADI_DECL_DEPRECATED_EXPORT
#  define MAILIMPORTERAKONADI_DECL_DEPRECATED_EXPORT MAILIMPORTERAKONADI_EXPORT MAILIMPORTERAKONADI_DECL_DEPRECATED
#endif

#ifndef MAILIMPORTERAKONADI_DECL_DEPRECATED_NO_EXPORT
#  define MAILIMPORTERAKONADI_DECL_DEPRECATED_NO_EXPORT MAILIMPORTERAKONADI_NO_EXPORT MAILIMPORTERAKONADI_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef MAILIMPORTERAKONADI_NO_DEPRECATED
#    define MAILIMPORTERAKONADI_NO_DEPRECATED
#  endif
#endif
#include <mailimporterakonadi_version.h>

#define MAILIMPORTERAKONADI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(MAILIMPORTERAKONADI_NO_DEPRECATED)
#  undef MAILIMPORTERAKONADI_DEPRECATED
#  define MAILIMPORTERAKONADI_DEPRECATED_EXPORT MAILIMPORTERAKONADI_EXPORT
#  define MAILIMPORTERAKONADI_DEPRECATED_NO_EXPORT MAILIMPORTERAKONADI_NO_EXPORT
#elif defined(MAILIMPORTERAKONADI_NO_DEPRECATED_WARNINGS)
#  define MAILIMPORTERAKONADI_DEPRECATED
#  define MAILIMPORTERAKONADI_DEPRECATED_EXPORT MAILIMPORTERAKONADI_EXPORT
#  define MAILIMPORTERAKONADI_DEPRECATED_NO_EXPORT MAILIMPORTERAKONADI_NO_EXPORT
#else
#  define MAILIMPORTERAKONADI_DEPRECATED MAILIMPORTERAKONADI_DECL_DEPRECATED
#  define MAILIMPORTERAKONADI_DEPRECATED_EXPORT MAILIMPORTERAKONADI_DECL_DEPRECATED_EXPORT
#  define MAILIMPORTERAKONADI_DEPRECATED_NO_EXPORT MAILIMPORTERAKONADI_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define MAILIMPORTERAKONADI_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define MAILIMPORTERAKONADI_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef MAILIMPORTERAKONADI_NO_DEPRECATED
#  define MAILIMPORTERAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT MAILIMPORTERAKONADI_VERSION
#endif
#ifdef MAILIMPORTERAKONADI_NO_DEPRECATED_WARNINGS
#  define MAILIMPORTERAKONADI_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef MAILIMPORTERAKONADI_DEPRECATED_WARNINGS_SINCE
#  ifdef MAILIMPORTERAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define MAILIMPORTERAKONADI_DEPRECATED_WARNINGS_SINCE MAILIMPORTERAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define MAILIMPORTERAKONADI_DEPRECATED_WARNINGS_SINCE MAILIMPORTERAKONADI_VERSION
#  endif
#endif

#ifndef MAILIMPORTERAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define MAILIMPORTERAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef MAILIMPORTERAKONADI_DEPRECATED
#  define MAILIMPORTERAKONADI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > MAILIMPORTERAKONADI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define MAILIMPORTERAKONADI_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* MAILIMPORTERAKONADI_EXPORT_H */
